@@ -20,7 +20,7 @@
 #  respective owners and no grant or license is provided thereof.
 
 package PDL::IO::Touchstone;
-$VERSION = 1.007;
+$VERSION = 1.008;
 
 use 5.010;
 use strict;
@@ -251,6 +251,28 @@ sub wsnp_fh
 	my $n_ports = n_ports($m);
 	my $n_freqs = $f->nelem;
 
+	if (ref($z0) eq 'PDL')
+	{
+		my $numz = $z0->nelem;
+
+		if ($numz > 1 && $numz != $n_ports)
+		{
+			croak("\$z0: must be single valued, or a vector of one z0 value per port: n_ports=$n_ports, z0=$z0");
+		}
+		elsif ($numz == $n_ports)
+		{
+			my $z01 = $z0->slice(0)->sclr;
+
+			my $zx = zeroes($numz)+$z01;
+			if (any $zx != $z0)
+			{
+				croak("All port impedances must be identical when writing Touchstone files: z0=$z0");
+			}
+		}
+
+		$z0 = $z0->slice(0)->sclr;
+	}
+
 	# Assume $f frequencies are in Hz if from_hz is not defined
 	# and always default writing in MHz if the user does not specify.
 	# This is consistent with rsnp() and common industry practice:
@@ -1197,6 +1219,11 @@ engineers can estimate signal behavior at various frequencies in their circuit
 designs.  Examples of RF components include capacitors, inductors, resistors,
 filters, power splitters, etc.
 
+This C<PDL::IO::Touchstone> module is very low-level and returns lots of
+variables to keep track of.  Instead, I recommend that you use L<RF::Component>
+module for an object-oriented approach which encapsulates the data returned by
+C<rsnp()> and will, most likely, simplify your RF component implementation.
+
 =head1 SYNOPSIS
 
 	use PDL::IO::Touchstone;
@@ -1654,6 +1681,8 @@ For example, re-compose $T from the C<m_to_pos_vecs> example.
 
 =over 4
 
+=item L<RF::Component> - An object-oriented encapsulation of C<PDL::IO::Touchstone>.
+
 =item Touchstone specification: L<https://ibis.org/connector/touchstone_spec11.pdf>
 
 =item S-parameter matrix transform equations: L<http://qucs.sourceforge.net/tech/node98.html>
